@@ -12,12 +12,12 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
+
+
 def redirect(start_response, location, permanent=None):
-    header=[('location',location),
-                 ('Content-Type',"text/plain")]
+    header = [('location', location), ('Content-Type', "text/plain")]
     if permanent:
         start_response('301 Moved Permanently', header)
     else:
         start_response('302 Moved Temporarily', header)
     return []
-
