@@ -23,17 +23,17 @@
 #include "wsgi.h"
 #include "mainloop.h"
 
-int debug;
-PyObject *pydeferqueue; 
-PyObject *py_base_module;  //to store the fapws.base python module
-PyObject *py_config_module; //to store the fapws.config module
-PyObject *py_registered_uri; //list containing the uri registered and their associated wsgi callback.
+extern int debug;
+extern PyObject *pydeferqueue; 
+extern PyObject *py_base_module;  //to store the fapws.base python module
+extern PyObject *py_config_module; //to store the fapws.config module
+extern PyObject *py_registered_uri; //list containing the uri registered and their associated wsgi callback.
 #define MAX_BUFF 32768  //read buffer size. bigger faster, but memory foot print bigger
 #define MAX_RETRY 9   //number of connection retry
 
-char * VERSION;
-PyObject *py_generic_cb; 
-char * date_format;
+extern char * VERSION;
+extern PyObject *py_generic_cb; 
+extern char * date_format;
 
 
 
@@ -89,6 +89,7 @@ void close_connection(struct client *cli)
     }
     close(cli->fd);
     free(cli);
+    PyErr_Clear();
 }
 
 
@@ -110,7 +111,7 @@ void timer_cb(struct ev_loop *loop, ev_timer *w, int revents)
     {
         ev_timer_stop(loop, w);
     }
-    Py_DECREF(resp);
+    Py_XDECREF(resp);
 }
 
 /*
@@ -296,6 +297,11 @@ int python_handler(struct client *cli)
     PyObject *pystart_response_class=PyObject_GetAttrString(py_base_module, "Start_response");
     PyObject *pystart_response=PyInstance_New(pystart_response_class, NULL, NULL);
     Py_DECREF(pystart_response_class);
+    if (PyErr_Occurred()) 
+    {
+             PyErr_Print();
+             return -500;
+    }
     // 7b) add the current date to the response object
     PyObject *py_response_header=PyObject_GetAttrString(pystart_response,"response_headers");
     char *sftime;
@@ -468,7 +474,7 @@ void write_cb(struct ev_loop *loop, struct ev_io *w, int revents)
         if (ret==0) //look for python callback and execute it
         {
             //uri not found
-            str_append3(response,"HTTP/1.0 500 Not found\r\nContent-Type: text/html\r\nServer: ", VERSION ,"\r\n\r\n<html><head><title>Page not found</head><body><p>Page not found!!!</p></body></html>", MAXHEADER);
+            str_append3(response,"HTTP/1.0 500 Not found\r\nContent-Type: text/html\r\nServer: ", VERSION ,"\r\n\r\n<html><head><title>Page not found</title></head><body><p>Page not found!!!</p></body></html>", MAXHEADER);
             write_cli(cli,response, strlen(response), revents);
             stop=1;
         } 
@@ -480,7 +486,7 @@ void write_cb(struct ev_loop *loop, struct ev_io *w, int revents)
         }
         else if (ret==-500)
         {
-            str_append3(response,"HTTP/1.0 500 Internal Server Error\r\nContent-Type: text/html\r\nServer: ", VERSION, "\r\n\r\n<html><head><title>Internal Server Error</head><body><p>Internal Server Error!!!</p></body></html>", MAXHEADER);
+            str_append3(response,"HTTP/1.0 500 Internal Server Error\r\nContent-Type: text/html\r\nServer: ", VERSION, "\r\n\r\n<html><head><title>Internal Server Error</title></head><body><p>Internal Server Error!!!</p></body></html>", MAXHEADER);
             write_cli(cli,response, strlen(response), revents);
             stop=1;
         }
@@ -506,12 +512,13 @@ void write_cb(struct ev_loop *loop, struct ev_io *w, int revents)
     else 
     {
         //we let the python developer to manage other HTTP command
-        if ((PyList_Check(cli->response_content))  && (cli->response_content_obj==NULL)) //we treat list object
+        if (((PyList_Check(cli->response_content))||(PyTuple_Check(cli->response_content)))  && (cli->response_content_obj==NULL)) //we treat list object
         {
+            int tuple = PyTuple_Check(cli->response_content);
             cli->response_iter_sent++;
-            if (cli->response_iter_sent<PyList_Size(cli->response_content)) 
+            if (cli->response_iter_sent<(tuple ? PyTuple_Size(cli->response_content) : PyList_Size(cli->response_content))) 
             {
-                PyObject *pydummy = PyList_GetItem(cli->response_content, cli->response_iter_sent);
+                PyObject *pydummy = tuple ? PyTuple_GetItem(cli->response_content, cli->response_iter_sent) : PyList_GetItem(cli->response_content, cli->response_iter_sent);
                 char *buff;
 #if (PY_VERSION_HEX < 0x02050000)
                 int buflen;
@@ -524,7 +531,7 @@ void write_cb(struct ev_loop *loop, struct ev_io *w, int revents)
                     // if this is a readable buffer, we send it. Other else, we ignore it.
                     if (write_cli(cli, buff, buflen, revents)==0)
                     {
-                        cli->response_iter_sent=PyList_Size(cli->response_content);  //break the for loop
+                        cli->response_iter_sent = tuple ? PyTuple_Size(cli->response_content) : PyList_Size(cli->response_content);  //break the for loop
                     }
                 }
                 else
@@ -607,8 +614,8 @@ void write_cb(struct ev_loop *loop, struct ev_io *w, int revents)
         } 
         else 
         {
-            //printf("wsgi output of is neither a list, neither a fileobject, neither an iterable object!!!!!\n");
-            PyErr_SetString(PyExc_TypeError, "Result must be a list, a fileobject or an iterable object");
+            printf("wsgi output of is neither a list, neither a fileobject, neither an iterable object!!!!!\n");
+            //PyErr_SetString(PyExc_TypeError, "Result must be a list, a fileobject or an iterable object");
             stop=1;
         }
     }// end of GET OR POST request
@@ -763,6 +770,15 @@ void sigint_cb(struct ev_loop *loop, ev_signal *w, int revents)
     ev_unloop(loop, EVUNLOOP_ALL);
 }
 
+/*
+This is the sigterm callback registered in the event loop
+*/
+void sigterm_cb(struct ev_loop *loop, ev_signal *w, int revents)
+{
+    ev_unloop(loop, EVUNLOOP_ALL);
+}
+
+
 /*
 This is the sigpipe callback registered in the event loop
 */
